qixnat - OHSU QIN XNAT helper
=============================

qixnat provides a XNAT facade and helper functions. See the
`documentation`_ for more information.

.. Targets:

.. _documentation: http://qixnat.readthedocs.org/en/latest/
